/*
 * This is plugin for nmp-package "Post-Compression".
 * He`s searching and replaces long class names on short class names, in the HTML code.
 *
 * An example of using:
 * var replaceClassNameInHTML = require("pc__replace_class_in_html");
 *
 * gulp.src("./*.html")
 *         replaceClassNameInHTML()
 *     ], shortNames));
 * 
 * Where:
 *  "shortNames" - an object of type JSON with rules replace the long words to short words.
 *
 * An example of the JSON object "shortNames":
 * {
 *     "class_in_html": {      // the name of the group names
 *         "someIdA": "a",     // long name: short name
 *         "someIdB": "b"
 *     }
 * }
 * 
 * An example of HTML code before:
 * <p class="someClassA"></p>
 * <p class="someClassA someClassB"></p>
 *
 * An example of HTML code after:
 * <p class="a"></p>
 * <p class="a b"></p>
 *
 */
module.exports = function() {
    return function (text, shortNames, typeContent) {
        var type = typeContent || "class_in_html",
            rules = {
                search: /(class)(\s{0,})(\=)(\s{0,})(\"|\')([^\"\']+)(\"|\')/gim,
                clear: /(^(class)(\s{0,})(\=)(\s{0,})(\"|\'))|((\s{0,})(\"|\')$)/gim,
                split: " "
            },
            arrayElements = text.match(rules.search);

        if (!shortNames[type]
            || !arrayElements) return text;

        for (var i = 0, l = arrayElements.length; i < l; i++) {
            var item = arrayElements[i],
                values = item.replace(rules.clear, "").split(rules.split);

            for (var j = 0, n = values.length; j < n; j++) {
                var selector = values[j];

                if (!selector || !shortNames[type][selector]) continue;
                values[j] = shortNames[type][selector];
            }

            var newContent = "class=\"" + values.join(" ") + "\"";
            text = text.replace(item, newContent);
        }

        return text;
    };
};